==> fca-poland-stock-database-lib-v2.3.0-aaa85e.zip: CHANGELOG.md <==
# v2.3.0
* Introducing wizard-filtering by dealer code

# v2.2.0
* Filter Wizard supports vehicle ids from now on.

# v2.1.1
* `\FCA\StockApi\Collection\Offer::find` converted to use aggregation pipeline only instead of "regular" Mongo's 
  `find()`.

# v2.1.0
* Wizard filters extended by:
   - version (`version.commercial_code`)
   - grups (`groups`)
   - tags/labels (`labels`)
* Wizard's brand filter can now take more than one brand ID as an argument (array)
* Introduced new expression operator: `all` (Mongo's `$all`).
* Filtering (Wizard) offers by equipment, groups or labels requires offers to contain all of specified values (hence
  `$all` operator), not just one (like in `$in`).
* Wizard-filtering by equipment now uses `equipment_options` field instead of `equipment.code`, since values from the
  former are used in the user-interactive search form. Note that still occur offers have that field (i.e. 
  `equipment_options`) TOTALY EMPTY.

# v2.0.1
* Version's commercial code can be `null`

# v2.0.0
* Code rewritten to be compatibile only for PHP >= 7.2 (strict types = on)

# v1.2.3
* Converting values to strings with `set***` methods of Filter Wizard

# v1.2.2
* Little bugfix `Collection\Filter\Wizard::removeGearboxType`
* Extended test for Filter Wizard

# v1.2.1
* Typo in `Collection\Filter\Wizard::setGearboxType` method name (lacks ending "s")

# v1.2.0
* Class `Collection\Filter\Stock` is now `Collection\Filter\Wizard`

# v1.1.0
* Changes related to `Collection\Filter\Stock` class:
  - rename *set** methods to *add**, like `setModel()` becomes `addModel()`
  - setters for array-structured properties now overwrite the property
  - add new methods related to array-structured properties: *clear** (like `clearBrandCode`), *remove** (like 
    `removeModel`)

# v1.0.10
* Field `model.groups.slug` definition
* Improved PSR-2 code style compability 

# v1.0.9
* Introducing `Document\Offer::toSimpleArray`

# v1.0.8
* support for financial calculators

# v1.0.7
* prevent calling toArray method on null

# v1.0.6
* removing trailing `s` from word `equipments`:
    - `\FCA\StockApi\Document\Offer::getEquipments` → `\FCA\StockApi\Document\Offer::getEquipment`
    - also in returned JSON data (`offer.equipments` → `offer.equipment`)

# v1.0.5
* Changelog init.
* Make `\FCA\StockApi\Document\Base::toArray` abstract.

==> fca-poland-stock-database-lib-v2.12.0-8678ae.zip: CHANGELOG.md <==
# v2.12.0
* New functionality: query for lowest prices (final, netto). Used to determine if offer should be labelled with
  "Lowest price" tag
* Removed any remnants of stamps.

# v2.11.1
* `model.groups` to `model.group` - bug fix

# v2.11.0
* Rename `model.groups` to `model.group`, fix unit tests

# v2.10.0
* Added `status` to simple offer data 

# v2.9.1
* Bugfix for equipment packs support. 

# v2.9.0
* Equipment packs support. 

# v2.8.0
* Introducing labels in `Document\Offer::toSimpleArray` (simplified offer details) 

# v2.7.1
* Support for INVENDUTO dealer (`null`) when setting dealer codes using Filter Wizard.

# v2.7.0
* Simplified offer's data now gets model's name from model's group at first, then from model's proper name

# v2.6.1
* Optimalization fix for 2.6.0.

# v2.6.0
* Offer's simplified details are now extended with dealer's code (`null` for Invenduto).

# v2.5.0
* When using `aggregate`, the `$near` conditions must be moved out from filters to aggregation stage

# v2.4.0
* Offer's simple details now contain also version's commercial code (as `version`)

# v2.3.0
* Introducing wizard-filtering by dealer code

# v2.2.0
* Filter Wizard supports vehicle ids from now on.

# v2.1.1
* `\FCA\StockApi\Collection\Offer::find` converted to use aggregation pipeline only instead of "regular" Mongo's 
  `find()`.

# v2.1.0
* Wizard filters extended by:
   - version (`version.commercial_code`)
   - grups (`groups`)
   - tags/labels (`labels`)
* Wizard's brand filter can now take more than one brand ID as an argument (array)
* Introduced new expression operator: `all` (Mongo's `$all`).
* Filtering (Wizard) offers by equipment, groups or labels requires offers to contain all of specified values (hence
  `$all` operator), not just one (like in `$in`).
* Wizard-filtering by equipment now uses `equipment_options` field instead of `equipment.code`, since values from the
  former are used in the user-interactive search form. Note that still occur offers have that field (i.e. 
  `equipment_options`) TOTALY EMPTY.

# v2.0.1
* Version's commercial code can be `null`

# v2.0.0
* Code rewritten to be compatibile only for PHP >= 7.2 (strict types = on)

# v1.2.3
* Converting values to strings with `set***` methods of Filter Wizard

# v1.2.2
* Little bugfix `Collection\Filter\Wizard::removeGearboxType`
* Extended test for Filter Wizard

# v1.2.1
* Typo in `Collection\Filter\Wizard::setGearboxType` method name (lacks ending "s")

# v1.2.0
* Class `Collection\Filter\Stock` is now `Collection\Filter\Wizard`

# v1.1.0
* Changes related to `Collection\Filter\Stock` class:
  - rename *set** methods to *add**, like `setModel()` becomes `addModel()`
  - setters for array-structured properties now overwrite the property
  - add new methods related to array-structured properties: *clear** (like `clearBrandCode`), *remove** (like 
    `removeModel`)

# v1.0.10
* Field `model.groups.slug` definition
* Improved PSR-2 code style compability 

# v1.0.9
* Introducing `Document\Offer::toSimpleArray`

# v1.0.8
* support for financial calculators

# v1.0.7
* prevent calling toArray method on null

# v1.0.6
* removing trailing `s` from word `equipments`:
    - `\FCA\StockApi\Document\Offer::getEquipments` → `\FCA\StockApi\Document\Offer::getEquipment`
    - also in returned JSON data (`offer.equipments` → `offer.equipment`)

# v1.0.5
* Changelog init.
* Make `\FCA\StockApi\Document\Base::toArray` abstract.
